==> dabstick-radio-0.92.tgz: dabstick-radio-0.92/sound-out/audiosink.h <==
#
/*
 *
 *    Copyright (C)  2009, 2010, 2011
 *    Jan van Katwijk (J.vanKatwijk@gmail.com)
 *    JFF Consultancy
 *
 *    This file is part of the JFF SDR (JSDR).
 *    Many of the ideas as implemented in ESDR are derived from
 *    other work, made available through the GNU general Public License. 
 *    All copyrights of the original authors are recognized.
 *
 *    JSDR is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    JSDR is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with ESDR; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef PA_WRITER
#define	PA_WRITER
#include	<stdio.h>
#include	<stdlib.h>
#include	<string.h>
#include	"jff-include.h"
#include	<portaudio.h>
#include	<stdio.h>
#include	"sound-defines.h"
#include	"ringbuffer.h"

#define		LOWLATENCY	0100
#define		HIGHLATENCY	0200
#define		VERYHIGHLATENCY	0300

class	audioSink  {
public:
			audioSink		(uint8_t);
			~audioSink		(void);
	int16_t		numberofDevices		(void);
	void		stop			(void);
	void		restart			(void);
	void		setMode			(int8_t, int32_t);
	void		audioOut		(int16_t *, int32_t);
const	char		*outputChannelwithRate	(int16_t, int32_t);
	int16_t		invalidDevice		(void);
	bool		isValidDevice		(int16_t);

	bool		selectDefaultDevice	(void);
	bool		selectDevice		(int16_t);
private:
	bool		OutputrateIsSupported	(int16_t, int32_t);

	int32_t		CardRate;
	uint8_t		Latency;
	bool		portAudio;
	bool		writerRunning;
	int16_t		numofDevices;
	int		paCallbackReturn;
	int16_t		bufSize;
	PaStream	*ostream;

	RingBuffer<int16_t>	*_O_Buffer;
	PaStreamParameters	outputParameters;
protected:
static	int		paCallback_o	(const void	*input,
	                                 void		*output,
	                                 unsigned long	framesperBuffer,
	                                 const PaStreamCallbackTimeInfo *timeInfo,
					 PaStreamCallbackFlags statusFlags,
	                                 void		*userData);
};

#endif

==> dabstick-radio-0.95.tgz: dabstick-radio-0.95/sound-out/audiosink.h <==
#
/*
 *
 *    Copyright (C)  2009, 2010, 2011
 *    Jan van Katwijk (J.vanKatwijk@gmail.com)
 *    JFF Consultancy
 *
 *    This file is part of the JFF SDR (JSDR).
 *    Many of the ideas as implemented in ESDR are derived from
 *    other work, made available through the GNU general Public License. 
 *    All copyrights of the original authors are recognized.
 *
 *    JSDR is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    JSDR is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with ESDR; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef PA_WRITER
#define	PA_WRITER
#include	<stdio.h>
#include	<stdlib.h>
#include	<string.h>
#include	"jff-include.h"
#include	<portaudio.h>
#include	<stdio.h>
//#include	"sound-defines.h"
#include	"ringbuffer.h"
#include	"fir-filters.h"
#include	<sndfile.h>
#define		LOWLATENCY	0100
#define		HIGHLATENCY	0200
#define		VERYHIGHLATENCY	0300

class	audioSink  {
public:
			audioSink		(uint8_t, int32_t);
			~audioSink		(void);
	int16_t		numberofDevices		(void);
const	char		*outputChannelwithRate	(int16_t, int32_t);
	void		stop			(void);
	void		restart			(void);
	void		audioOut		(int16_t *, int32_t);
	void		audioOut		(int16_t *, int32_t, int32_t);
	int32_t		putSample		(DSPCOMPLEX);
	int32_t		putSamples		(DSPCOMPLEX *, int32_t);
	int16_t		invalidDevice		(void);
	bool		isValidDevice		(int16_t);

	bool		selectDefaultDevice	(void);
	bool		selectDevice		(int16_t);
	void		startDumping		(SNDFILE *);
	void		stopDumping		(void);
private:
	bool		OutputrateIsSupported	(int16_t, int32_t);
	LowPassFIR	*upFilter;
	int32_t		CardRate;
	uint8_t		Latency;
	bool		portAudio;
	bool		writerRunning;
	int16_t		numofDevices;
	int		paCallbackReturn;
	int16_t		bufSize;
	PaStream	*ostream;
	SNDFILE		*dumpFile;
	RingBuffer<float>	*_O_Buffer;
	PaStreamParameters	outputParameters;
protected:
static	int		paCallback_o	(const void	*input,
	                                 void		*output,
	                                 unsigned long	framesperBuffer,
	                                 const PaStreamCallbackTimeInfo *timeInfo,
					 PaStreamCallbackFlags statusFlags,
	                                 void		*userData);
};

#endif
